"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const src_1 = require("../../src");
const chai = require('chai');
chai.use(require('chai-as-promised'));
const XRPMccConnection = {
    url: process.env.XRP_URL || "",
    username: process.env.XRP_USERNAME || "",
    password: process.env.XRP_PASSWORD || "",
};
describe("Block Xrp base test ", function () {
    let MccClient;
    let block;
    const blockNumber = 72387695;
    before(async function () {
        MccClient = new src_1.MCC.XRP(XRPMccConnection);
        block = await MccClient.getBlock(blockNumber);
    });
    it("Should get block", async function () {
        (0, chai_1.expect)(block).to.not.eq(undefined);
    });
    it("Should get block number ", async function () {
        (0, chai_1.expect)(block.number).to.eq(blockNumber);
    });
    it("Should get block hash ", async function () {
        (0, chai_1.expect)(block.blockHash).to.eq("2492B09472F24DB37B124A2F9D1D0FA6883EF0FE51494938A54E6CD93295C086");
    });
    it("Should get block standard hash ", async function () {
        (0, chai_1.expect)(block.stdBlockHash).to.eq("2492B09472F24DB37B124A2F9D1D0FA6883EF0FE51494938A54E6CD93295C086");
    });
    it("Should get block timestamp ", async function () {
        (0, chai_1.expect)(block.unixTimestamp).to.eq(1655418890);
    });
    it("Should get transaction ids ", async function () {
        (0, chai_1.expect)(block.transactionIds.length).to.eq(42);
        (0, chai_1.expect)(block.stdTransactionIds).contains("B84F30266D6297E9E4EFB7B0600E486ECD653587FFE001B05CAE5533CEF1C5BE");
        (0, chai_1.expect)(block.stdTransactionIds).contains("DB91A3AECACC060EFA45B1922E278DEB5B7F5B4FC4FED5829072B66A1DFF31E1");
    });
    it("Should get transaction standard ids ", async function () {
        (0, chai_1.expect)(block.stdTransactionIds.length).to.eq(42);
    });
    it("Should get transaction count ", async function () {
        (0, chai_1.expect)(block.transactionCount).to.eq(42);
    });
    it("Should get transaction count 2", async function () {
        delete block.data.result.ledger.transactions;
        (0, chai_1.expect)(block.transactionCount).to.eq(0);
    });
    it("Should get block", async function () {
        const block2 = await MccClient.getBlock(blockNumber.toString());
        (0, chai_1.expect)(block2).to.not.eq(undefined);
    });
    it("Should not get block", async function () {
        await (0, chai_1.expect)(MccClient.getBlock("0x2492B09472F24DB37B124A2F9D1D0FA6883EF0FE51494938A54E6CD93295C086")).to.eventually.be.rejected;
    });
});
//# sourceMappingURL=block.test.js.map